The label of a transform could be the value of the field name from
each object of class trans (or transform),
but also the name of the transform
function itself, if it is a primitive function or just calls one function.
Each object of class trans (or transform)
should have a field name
which can be returned by the present function.
The function examines the field transform.
If this field contains a primitive function (see rlang::is_primitive()),
or if there is just one function call in the body of this transform
function, we can also return the name of this called function.
If there is no field name and no single function is called from the
function defined in the field transform,
a generic function name "f." is returned.