If some of the variables are non-normally distributed, a transform may
improve the prediction. The transforms are passed to the function as a named
list, where the name of a list entry must correspond to the name of the
variable in the data which is to be transformed.
Predefined transforms can be found in the package scales, where they are
used for axis transformations as a preparation for plotting. The package
scales also contains a function trans_new which can be used
to define new transforms.
In the context of destructively measured sawn timber properties, the type of
destructive test applied is of interest. If the dataset data contains a
variable loadtype which consistently throughout the dataset has either the
value "t" (i.e. all sawn timber has been tested in tension) or the
value "be" (i.e. all sawn timber has been tested in bending, edgewise),
then the returned object also has a field loadtype with that value.
One can also calculate a simbase under the assumption that the correlations
are different for different subgroups of the data. This is done by grouping
the dataset data prior to passing it to the function,
using dplyr::group_by(). In this case, several objects of
class simbase_covar are created and joined together in a tibble::tibble --
see also simbase_list().